defaultable library
Classes
- Defaultable
- A class that serves as both an annotation and an interface to mark classes for default instance generation.
- DefaultableRegistry
-
An annotation that triggers the generation of the global
getInstance()function. Place this in one file in your project.
Constants
- defaultableRegistry → const DefaultableRegistry
- A constant instance of DefaultableRegistry for use as an annotation.